searchData={"items":[{"type":"module","title":"LiveIsolatedComponent","doc":"Functions for testing LiveView stateful components in isolation easily.","ref":"LiveIsolatedComponent.html"},{"type":"macro","title":"LiveIsolatedComponent.assert_handle_event/4","doc":"Asserts that a given handle event has been received.\n\nDepending on the number of parameters, different parts are checked:\n\n- With no parameters, just that a handle_event message has been received.\n- With one parameter, just the event name is checked.\n- With two parameters, both event name and the parameters are checked.\n- The optional last argument is the timeout, defaults to 500 milliseconds\n\nIf you just want to check the parameters without checking the event name,\npass `nil` as the event name.","ref":"LiveIsolatedComponent.html#assert_handle_event/4"},{"type":"macro","title":"LiveIsolatedComponent.assert_handle_event_return/2","doc":"Asserts the return value of a handle_event","ref":"LiveIsolatedComponent.html#assert_handle_event_return/2"},{"type":"macro","title":"LiveIsolatedComponent.assert_handle_info/3","doc":"Asserts that a given handle_info event has been received.\n\nIf only the view is passed, only that a handle_info is received is checked.\nWith an optional event name, we check that too.\nThe third argument is an optional timeout, defaults to 500 milliseconds.","ref":"LiveIsolatedComponent.html#assert_handle_info/3"},{"type":"function","title":"LiveIsolatedComponent.live_assign/2","doc":"Updates the assigns of the component.\n\n    {:ok, view, _html} = live_isolated_component(SomeComponent, assigns: %{description: \"blue\"})\n\n    live_assign(view, %{description: \"red\"})","ref":"LiveIsolatedComponent.html#live_assign/2"},{"type":"function","title":"LiveIsolatedComponent.live_assign/3","doc":"Updates the key in assigns of the component.\n\n    {:ok, view, _html} = live_isolated_component(SomeComponent, assigns: %{description: \"blue\"})\n\n    live_assign(view, :description, \"red\")","ref":"LiveIsolatedComponent.html#live_assign/3"},{"type":"macro","title":"LiveIsolatedComponent.live_isolated_component/2","doc":"Renders the given component in isolation and live so you can tested like you would\ntest any LiveView.\n\nIt accepts the following options:\n  - `:assigns` accepts a map of assigns for the component.\n  - `:handle_event` accepts a handler for the `handle_event` callback in the LiveView.\n  - `:handle_info` accepts a handler for the `handle_info` callback in the LiveView.\n  - `:slots` accepts different slot descriptors.","ref":"LiveIsolatedComponent.html#live_isolated_component/2"},{"type":"macro","title":"More about slots - LiveIsolatedComponent.live_isolated_component/2","doc":"For defining slots, you need to use the `slot/2` macro. If you just pass a slot\nto `:slots`, it will be taken as a default sot (`@inner_block` inside the component).\n\nYou can also pass a map or keywords to `:slots`. In this case, the key is considered\nto be the slot name and the value, the different slots. Remember that the default slot's\nname is `inner_block`.\n\nFor passing multiple slots for the same name, you have two options:any()\n\n1. You can give an array of slots as the value in the map or the keywords.\n2. You can pass the same name multiple times with different slots. This option\n   is only available if you are using keywords, as this data structure preserves\n   all values.","ref":"LiveIsolatedComponent.html#live_isolated_component/2-more-about-slots"},{"type":"macro","title":"LiveIsolatedComponent.refute_handle_event/4","doc":"Refutes that a given handle event has been received.\n\nDepending on the number of parameters, different parts are checked:\n\n- With no parameters, just that a handle_event message has not been received.\n- With one parameter, just the event name is checked.\n- With two parameters, both event name and the parameters are checked.\n- The optional last argument is the timeout, defaults to 500 milliseconds\n\nIf you just want to check the parameters without checking the event name,\npass `nil` as the event name.","ref":"LiveIsolatedComponent.html#refute_handle_event/4"},{"type":"macro","title":"LiveIsolatedComponent.refute_handle_info/3","doc":"Asserts that a given handle_info event has not been received.\n\nIf only the view is passed, only that a handle_info is not received is checked.\nWith an optional event name, we check that too.\nThe third argument is an optional timeout, defaults to 500 milliseconds.","ref":"LiveIsolatedComponent.html#refute_handle_info/3"},{"type":"macro","title":"LiveIsolatedComponent.slot/2","doc":"Macro to define slots. Accepts a map or keywords and a block.\nThe block needs to return a template (use a `sigil_H`).\n\nThe arguments can be anything and they will be passed to the slot\nas attributes. There is only one special attribute that will not\nbe passed though:\n\n1. `let` behaves like in components, letting the component\n   pass some value into the slot.","ref":"LiveIsolatedComponent.html#slot/2"},{"type":"macro","title":"Example - LiveIsolatedComponent.slot/2","doc":"```\n> slot(let: {key, value}) do\n    ~H[\n     \n       Title coming from assigns:   \n       Key coming from let   \n       Value coming from let  \n     \n    ]\n  end\n```","ref":"LiveIsolatedComponent.html#slot/2-example"},{"type":"macro","title":"Conversion - LiveIsolatedComponent.slot/2","doc":"In case you are wondering how to convert a slot in HEEX\nto the slot macro, let's do a simple conversion from a\nnamed slot with attributes:any()\n\n```heex\n \n   Received value from parent component is   \n \n```\n\nFor converting this, we notice three different parts:\n\n1. The slot name. In this case, `:slot_name`.\n2. The slot attributes. In this case, `attr_1={5} attr_2=\"hola\" let={value}`.\n3. The slot content (or inner_block). In this case, the `span`.\n\nThus, we just need to pass to the `slots` options the following value (just\nshowing the keyword options to `live_isolated_component`):\n\n```elixir\n[\n  slots: [\n    slot_name: slot(attr_1: 5, attr_2: \"hola\", let: value) do\n      ~H[ Received value from parent component is   ]\n    end\n  ]\n]\n```","ref":"LiveIsolatedComponent.html#slot/2-conversion"}],"content_type":"text/markdown"}